@@ -53,5 +53,5 @@ urlpatterns = patterns('',
     url(r'^api/', include('Theophrastus.api.urls')),
 
     # django-selectable.
-    url(r'^selectable/', include('selectable.urls')),
+    url(r'^newsletters/selectable/', include('selectable.urls')),
 )
